user.SimpleUser

|  | ## Cheshire3 Object Model: Class SimpleUser

Module user :: Class SimpleUser

## Class SimpleUser
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
             baseObjects.User --+
                                |
                               SimpleUser

Instance Methods

_handleConfigNode(self, session, node)
hasFlag(self, session, flag, object="") Check whether or not the user has the specified flag.
check_password(self, session, password)
Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

simpleNodes |
username |
password |
email |
address |
tel |
realName |
description |
flags |
allFlags |
resultSetIds |
Inherited from `baseObjects.User`: `rights` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### _handleConfigNode(self, session, node) | source code
Overrides: configParser.C3Object._handleConfigNode

### hasFlag(self, session, flag, object="") | source code
Check whether or not the user has the specified flag. This flag may be set regarding a particular object, for example write access to a particular store. Overrides: baseObjects.User.hasFlag (inherited documentation)

### check_password(self, session, password) | source code

Class Variable Details

    ### simpleNodes Value:
        ['username',
         'password',
         'email',
         'address',
         'tel',
         'realName',
         'description',
         'passwordType']

    ### username Value:
        ""

    ### password Value:
        ""

    ### email Value:
        ""

    ### address Value:
        ''

    ### tel Value:
        ''

    ### realName Value:
        ""

    ### description Value:
        ''

    ### flags Value:
        {}

    ### allFlags Value:
        {'c3r:administrator': 'Administrator flag. Inherits all others.',
         'info:srw/operation/1/create': 'Create record within this store',
         'info:srw/operation/1/delete': 'Delete existing record from store',
         'info:srw/operation/1/metadata': 'Modify metadata of record within st\
        ore',
         'info:srw/operation/1/replace': 'Replace existing record within store\
        ',
         'info:srw/operation/2/cluster': 'Run clustering process for this obje\
        ...

    ### resultSetIds Value:
        []